Module double_checked

Module double_checked 

Double-Checked Lock Executor

Provides a double-checked lock executor for executing tasks with condition checking and prepare lifecycle support.

Structs

CallbackError
Common error information for prepare lifecycle callbacks.
DoubleCheckedLock
Entry type for one-shot double-checked lock execution.
DoubleCheckedLockBuilder
Convenience builder state with lock attached.
DoubleCheckedLockExecutor
Reusable double-checked lock executor.
DoubleCheckedLockReadyBuilder
Convenience builder state with tester attached.
ExecutionContext
Execution context (state after task execution)
ExecutionLogger
Logger for double-checked execution (condition unmet, prepare failures, prepare commit failures, and prepare rollback failures).
ExecutorBuilder
Initial builder for super::DoubleCheckedLockExecutor.
ExecutorLockBuilder
Builder state after a lock has been attached.
ExecutorReadyBuilder
Builder state after the required condition tester has been configured.

Enums

ExecutionResult
Task execution result
ExecutorError
Executor error types.