ExecutorError

Enum ExecutorError 

pub enum ExecutorError<E> {
    TaskFailed(E),
    Panic(CallbackError),
    PrepareFailed(CallbackError),
    PrepareCommitFailed(CallbackError),
    PrepareRollbackFailed {
        original: CallbackError,
        rollback: CallbackError,
    },
}
Executor error types.

Type Parameters

  • E - The original error type from task execution

Examples

use qubit_dcl::double_checked::ExecutorError;
use qubit_dcl::double_checked::CallbackError;

let error: ExecutorError<String> =
    ExecutorError::TaskFailed("task failed".to_string());
println!("Error: {}", error);

let error_with_msg: ExecutorError<String> =
    ExecutorError::PrepareFailed(CallbackError::from_display("Service is not running"));
println!("Error: {}", error_with_msg);

Variants



TaskFailed(E)

Task execution failed with original error



Panic(CallbackError)

Task execution panicked.



PrepareFailed(CallbackError)

Preparation action failed



PrepareCommitFailed(CallbackError)

Commit action for a successfully completed prepare action failed.



PrepareRollbackFailed

Rollback action for a successfully completed prepare action failed.

Fields

original: CallbackError

The original error that triggered the rollback

rollback: CallbackError

The error that occurred during prepare rollback

Implementations

Source

impl<E> ExecutorError<E>

pub fn callback_type(&self) -> Option<&'static str>

Returns the callback type label, when the error comes from a callback and the type is available.

This returns None for task failures and callback errors without associated type labels.

Returns

Some(label) for callback failures that carry callback type metadata, or None for task failures and untyped callback failures.