pub struct ExecutorLockBuilder<L, T> { /* private fields */ }Expand description
Builder state after a lock has been attached.
Call Self::when to configure the required condition tester.
Type Parameters
L- The lock type implementingLock<T>.T- The data type protected by the lock.
Implementations
Sourceimpl<L, T> ExecutorLockBuilder<L, T>where
L: Lock<T>,
impl<L, T> ExecutorLockBuilder<L, T>where
L: Lock<T>,
Sourcepub fn log_unmet_condition(
self,
level: Level,
message: impl Into<String>,
) -> Self
pub fn log_unmet_condition( self, level: Level, message: impl Into<String>, ) -> Self
Configures logging when the double-checked condition is not met.
Sourcepub fn disable_unmet_condition_logging(self) -> Self
pub fn disable_unmet_condition_logging(self) -> Self
Disables logging when the double-checked condition is not met.
Sourcepub fn log_prepare_failure(
self,
level: Level,
message_prefix: impl Into<String>,
) -> Self
pub fn log_prepare_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self
Configures logging when the prepare action fails.
Sourcepub fn disable_prepare_failure_logging(self) -> Self
pub fn disable_prepare_failure_logging(self) -> Self
Disables logging when the prepare action fails.
Sourcepub fn log_prepare_commit_failure(
self,
level: Level,
message_prefix: impl Into<String>,
) -> Self
pub fn log_prepare_commit_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self
Configures logging when the prepare commit action fails.
Sourcepub fn disable_prepare_commit_failure_logging(self) -> Self
pub fn disable_prepare_commit_failure_logging(self) -> Self
Disables logging when the prepare commit action fails.
Sourcepub fn log_prepare_rollback_failure(
self,
level: Level,
message_prefix: impl Into<String>,
) -> Self
pub fn log_prepare_rollback_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self
Configures logging when the prepare rollback action fails.
Sourcepub fn disable_prepare_rollback_failure_logging(self) -> Self
pub fn disable_prepare_rollback_failure_logging(self) -> Self
Disables logging when the prepare rollback action fails.
Sourcepub fn when<Tst>(self, tester: Tst) -> ExecutorReadyBuilder<L, T>
pub fn when<Tst>(self, tester: Tst) -> ExecutorReadyBuilder<L, T>
Configures the required double-checked condition.
The tester is executed outside and inside the lock. State read by the outside check must be safe to access without this executor’s lock.
Parameters
tester- The reusable condition tester.
Returns
The builder state that can configure prepare callbacks and build the executor.
Sourcepub fn catch_panics(self) -> Self
pub fn catch_panics(self) -> Self
Enables panic capture for tester, prepare callbacks, and task execution.
Sourcepub fn set_catch_panics(self, catch_panics: bool) -> Self
pub fn set_catch_panics(self, catch_panics: bool) -> Self
Sets whether panic capture for tester, prepare callbacks, and task execution is enabled.
Sourcepub fn disable_catch_panics(self) -> Self
pub fn disable_catch_panics(self) -> Self
Disables panic capture for tester, prepare callbacks, and task execution.