pub struct DoubleCheckedLockReadyBuilder<L, T> { /* private fields */ }Expand description
Convenience builder state with tester attached.
Implementations
Sourceimpl<L, T> DoubleCheckedLockReadyBuilder<L, T>where
L: Lock<T>,
impl<L, T> DoubleCheckedLockReadyBuilder<L, T>where
L: Lock<T>,
Sourcepub fn log_unmet_condition(
self,
level: Level,
message: impl Into<String>,
) -> Self
pub fn log_unmet_condition( self, level: Level, message: impl Into<String>, ) -> Self
Configures logging when the double-checked condition is not met.
Sourcepub fn disable_unmet_condition_logging(self) -> Self
pub fn disable_unmet_condition_logging(self) -> Self
Disables logging when the double-checked condition is not met.
Sourcepub fn log_prepare_failure(
self,
level: Level,
message_prefix: impl Into<String>,
) -> Self
pub fn log_prepare_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self
Configures logging when the prepare action fails.
Sourcepub fn disable_prepare_failure_logging(self) -> Self
pub fn disable_prepare_failure_logging(self) -> Self
Disables logging when the prepare action fails.
Sourcepub fn log_prepare_commit_failure(
self,
level: Level,
message_prefix: impl Into<String>,
) -> Self
pub fn log_prepare_commit_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self
Configures logging when the prepare commit action fails.
Sourcepub fn disable_prepare_commit_failure_logging(self) -> Self
pub fn disable_prepare_commit_failure_logging(self) -> Self
Disables logging when the prepare commit action fails.
Sourcepub fn log_prepare_rollback_failure(
self,
level: Level,
message_prefix: impl Into<String>,
) -> Self
pub fn log_prepare_rollback_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self
Configures logging when the prepare rollback action fails.
Sourcepub fn disable_prepare_rollback_failure_logging(self) -> Self
pub fn disable_prepare_rollback_failure_logging(self) -> Self
Disables logging when the prepare rollback action fails.
Sourcepub fn catch_panics(self) -> Self
pub fn catch_panics(self) -> Self
Enables panic capture for tester, prepare callbacks, and task execution.
Sourcepub fn set_catch_panics(self, catch_panics: bool) -> Self
pub fn set_catch_panics(self, catch_panics: bool) -> Self
Sets whether panic capture for tester, prepare callbacks, and task execution is enabled.
Sourcepub fn disable_catch_panics(self) -> Self
pub fn disable_catch_panics(self) -> Self
Disables panic capture for tester, prepare callbacks, and task execution.
Sourcepub fn rollback_prepare<Rn, E>(self, rollback_prepare_action: Rn) -> Self
pub fn rollback_prepare<Rn, E>(self, rollback_prepare_action: Rn) -> Self
Sets the rollback action for prepare.
Sourcepub fn commit_prepare<Rn, E>(self, commit_prepare_action: Rn) -> Self
pub fn commit_prepare<Rn, E>(self, commit_prepare_action: Rn) -> Self
Sets the commit action for prepare.
Sourcepub fn build(self) -> DoubleCheckedLockExecutor<L, T>
pub fn build(self) -> DoubleCheckedLockExecutor<L, T>
Builds a reusable DoubleCheckedLockExecutor.
Sourcepub fn call<C, R, E>(self, task: C) -> ExecutionContext<R, E>
pub fn call<C, R, E>(self, task: C) -> ExecutionContext<R, E>
Runs a callable task with one-shot executor creation.
Sourcepub fn execute<Rn, E>(self, task: Rn) -> ExecutionContext<(), E>
pub fn execute<Rn, E>(self, task: Rn) -> ExecutionContext<(), E>
Runs a runnable task with one-shot executor creation.
Sourcepub fn call_with<C, R, E>(self, task: C) -> ExecutionContext<R, E>where
C: CallableWith<T, R, E>,
E: Display,
pub fn call_with<C, R, E>(self, task: C) -> ExecutionContext<R, E>where
C: CallableWith<T, R, E>,
E: Display,
Runs a callable task with mutable protected data.
Sourcepub fn execute_with<Rn, E>(self, task: Rn) -> ExecutionContext<(), E>where
Rn: RunnableWith<T, E>,
E: Display,
pub fn execute_with<Rn, E>(self, task: Rn) -> ExecutionContext<(), E>where
Rn: RunnableWith<T, E>,
E: Display,
Runs a runnable task with mutable protected data.