ExecutorBuilder

Struct ExecutorBuilder 

pub struct ExecutorBuilder { /* private fields */ }
Initial builder for super::DoubleCheckedLockExecutor.

This state has no lock yet. Call Self::on to attach the lock.

Implementations

Source

impl ExecutorBuilder

pub fn log_unmet_condition( self, level: Level, message: impl Into<String>, ) -> Self

Configures logging when the double-checked condition is not met.

pub fn disable_unmet_condition_logging(self) -> Self

Disables logging when the double-checked condition is not met.

pub fn log_prepare_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self

Configures logging when the prepare action fails.

pub fn disable_prepare_failure_logging(self) -> Self

Disables logging when the prepare action fails.

pub fn log_prepare_commit_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self

Configures logging when the prepare commit action fails.

pub fn disable_prepare_commit_failure_logging(self) -> Self

Disables logging when the prepare commit action fails.

pub fn log_prepare_rollback_failure( self, level: Level, message_prefix: impl Into<String>, ) -> Self

Configures logging when the prepare rollback action fails.

pub fn disable_prepare_rollback_failure_logging(self) -> Self

Disables logging when the prepare rollback action fails.

pub fn on<L, T>(self, lock: L) -> ExecutorLockBuilder<L, T>
where L: Lock<T>,

Attaches the lock protected by this executor.

Parameters
  • lock - The lock handle. Arc-based lock wrappers can be cloned and stored here for reusable execution.
Returns

The builder state that can configure the required tester.

pub fn catch_panics(self) -> Self

Enables panic capture for tester, prepare callbacks, and task execution.

pub fn set_catch_panics(self, catch_panics: bool) -> Self

Sets whether panic capture for tester, prepare callbacks, and task execution is enabled.

pub fn disable_catch_panics(self) -> Self

Disables panic capture for tester, prepare callbacks, and task execution.